@@ -63,7 +63,7 @@ has 'abs_file' => (
     isa      => File,
     lazy     => 1,
     init_arg => undef,
-    default  => sub { $_[0]->file->absolute->resolve },
+    default  => sub { $_[0]->file->absolute->cleanup },
 );
 
 use overload '""' => '_stringify';
