@@ -1301,9 +1301,7 @@ sub _files_actions_after_success {
             $self->_rename_file( @$pair );
         }
     }
-    for my $file ( @{ $self->files->{delete} } ) {
-        $file->delete if $file->exists;
-    }
+    $_->delete for @{ $self->_use_files->{delete} };
 }
 
 sub _file_exists {
